pub struct MemorySubscriptionFilter { /* private fields */ }Expand description
In memory representation of a subscription filter. This is what we will use to evaluate whether a given subscription matches an incoming event.
Implementations
Sourceimpl MemorySubscriptionFilter
impl MemorySubscriptionFilter
Sourcepub async fn new<Resolver: SearchParameterResolve>(
tenant_id: &TenantId,
project_id: &ProjectId,
resolver: Arc<Resolver>,
value: Subscription,
) -> Result<Self, OperationOutcomeError>
pub async fn new<Resolver: SearchParameterResolve>( tenant_id: &TenantId, project_id: &ProjectId, resolver: Arc<Resolver>, value: Subscription, ) -> Result<Self, OperationOutcomeError>
Creates a MemorySubscriptionFilter from a subscription.
Resolves and validates the search parameters specified in the subscription criteria and constructs the corresponding FHIRPath-based filter.
Errors
Returns an [OperationOutcomeError] if:
- the subscription criteria has an invalid format;
- the criteria contains an invalid resource type;
- a search parameter cannot be resolved for the resource type;
- a chained search parameter is used;
- a resolved search parameter does not have a
FHIRPathexpression; - an unsupported result parameter is present in the criteria; or
- the subscription does not contain criteria.
Arguments
tenant_id- The tenant owning the subscription.project_id- The project owning the subscription.resolver- Resolver used to look up search parameters.value- The subscription from which to construct the filter.